local anim8 = require 'anim8'
local image, animation

function love.load()
	bulletspeed = 5000
	shoot = love.audio.newSource("gunshot.wav")
	bullets = {
		x = 0,
		y = 0,
		dx = 0,
		dy = 0
		}
	pointer = love.graphics.newImage("CrossHair.png")
	background = love.graphics.newImage("grass_square.png")
	player = {
		x = 0,
		y = 0,
		health = 100,
		armor = 0,
		image = love.graphics.newImage("citizenplayer_handgun.png"),
		angle = 0,
		footstep_angle = 0,
		speed = .1
		}
	zombie = {
		x = 0,
		y = 0,
		health = 25,
		image1 = love.graphics.newImage("citizenzombie1.png"),
		image2 = love.graphics.newImage("citizenzombie2.png"),
		image3 = love.graphics.newImage("citizenzombie3.png"),
		images = {image1, image2, image3}
		}
	current_zom = math.ceil(math.random(1,3))
	if current_zom == 1 then
		current_zom = zombie.image1
	elseif current_zom == 2 then
		current_zom = zombie.image2
	elseif current_zom == 3 then
		current_zom = zombie.image3
	end
	player.x = 300
	player.y = 300
	
	footsteps = love.graphics.newImage("footsteps.png")
	local g = anim8.newGrid(64,64,footsteps:getWidth(), footsteps:getHeight())
	animation = anim8.newAnimation("bounce",g("1-5,1"), player.speed)
	animation:pause()
end
	
function love.update(dt)
	local mousex = love.mouse.getX()
    local mousey = love.mouse.getY()
    player.angle = (math.atan2(mousey - player.y, mousex - player.x) + 1.52)
	
	for i,v in ipairs(bullets) do
		v.x = v.x + (v.dx * dt)
		v.y = v.y + (v.dy * dt)
	end
	if love.keyboard.isDown("a") then
		animation_running = 1
		animation:resume()
		player.x = player.x - 1
		player.footstep_angle = 1.6
	elseif love.keyboard.isDown("d") then
		animation_running = 1
		animation:resume()
		player.x = player.x + 1
		player.footstep_angle = 1.6
	end
	if love.keyboard.isDown("w") then
		animation_running = 1
		animation:resume()
		player.y = player.y - 1
		player.footstep_angle = 0
	elseif love.keyboard.isDown("s") then
		animation_running = 1
		animation:resume()
		player.y = player.y + 1
		player.footstep_angle = 0
	end
	if not love.keyboard.isDown("d") and not love.keyboard.isDown("a") and not love.keyboard.isDown("w") and not love.keyboard.isDown("s") then
		animation_running = 0
	end
	animation:update(dt)
end

function love.draw()
    love.graphics.draw(background,0,0,0,3,3,0,0)
	if animation_running == 1 then	
		animation:draw(footsteps, player.x, player.y, player.footstep_angle, 1.7, 1.7, 20, 32)
	end
	love.graphics.draw(player.image,player.x,player.y,player.angle, 1, 1, 32, 53)
	love.graphics.draw(pointer,love.mouse.getX(),love.mouse.getY(),0, 1, 1, 24, 24)
	love.graphics.setColor(120,120,120)
	if shooting == 1 then
		for i,v in ipairs(bullets) do
			love.graphics.circle("fill",v.x,v.y,2)
		end
	end
	love.graphics.draw(current_zom,300, 300)
end

function love.mousepressed(x, y, button)
	if button == "l" then
		shooting = 1
		startX = player.x
		startY = player.y
		originx = love.mouse.getX()
		originy = love.mouse.getY()
		
		angle = math.atan2((originy - player.y),(originx - player.x))
		
		bulletDx = bulletspeed * math.cos(angle)
		bulletDy = bulletspeed * math.sin(angle)
		
		table.insert(bullets, {x = startX, y = startY, dx = bulletDx, dy = bulletDy})
	else
		shooting = 0
	end
end